import { StableContextProps } from './StableContext';
import { DynamicContextProps } from './DynamicContext';
export type CombinedContextProps = StableContextProps & DynamicContextProps;
/**
 * Hook to access stable configuration values
 * Use this when components only need configuration data
 */
export declare const useStableContext: () => StableContextProps;
/**
 * Hook to access dynamic state values
 * Use this when components only need dynamic state
 */
export declare const useDynamicContext: () => DynamicContextProps;
/**
 * Hook to access both stable and dynamic contexts
 * Use this for components that need both types of data
 * This maintains backward compatibility with the old GlobalContext
 */
export declare const useGlobalContext: () => CombinedContextProps;
/**
 * Legacy hook for backward compatibility
 * @deprecated Use useGlobalContext, useStableContext, or useDynamicContext instead
 */
export declare const useTimelineContext: () => CombinedContextProps;
