import { Theme } from '@models/Theme';
import { TimelineMode } from '@models/TimelineModel';
/**
 * Main container for the entire vertical timeline component.
 */
export declare const TimelineVerticalWrapper: import("styled-components/dist/types").IStyledComponentBase<"web", import("styled-components").FastOmit<import("react").DetailedHTMLProps<import("react").HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>> & string;
/**
 * Props for the VerticalItemWrapper component.
 */
interface VerticalItemWrapperProps {
    /** Controls layout for alternating cards mode. */
    $alternateCards?: boolean;
    /** Explicit height for the card content area. */
    $cardHeight?: number;
    /** Style adjustments for items without card content. */
    $cardLess?: boolean;
    /** Indicates if the item is part of a nested timeline structure. */
    $isNested?: boolean;
    /** Theme object for styling. */
    theme?: Theme;
}
/**
 * Wrapper for a single timeline item (row), containing title, point, and content.
 * Handles visibility animation and basic layout.
 */
export declare const VerticalItemWrapper: import("styled-components/dist/types").IStyledComponentBase<"web", import("styled-components/dist/types").Substitute<import("react").DetailedHTMLProps<import("react").LiHTMLAttributes<HTMLLIElement>, HTMLLIElement>, VerticalItemWrapperProps>> & string;
/**
 * Props for the TimelineCardContentWrapper component.
 */
interface TimelineCardContentWrapperProps {
    /** Controls layout for alternating cards mode. */
    $alternateCards?: boolean;
    /** Style adjustments for items without card content. */
    $cardLess?: boolean;
    /** Reverses the order of elements (content/point/title). */
    $flip?: boolean;
    /** Flag for mobile-specific styling adjustments. */
    $isMobile?: boolean;
    /** Indicates if the timeline item has no title, affecting layout. */
    $noTitle?: boolean;
    /** Explicit height for the card content area. */
    height?: number;
}
/**
 * Wrapper for the main content card of a timeline item.
 * Handles width, alignment, order, and visibility animation based on props.
 */
export declare const TimelineCardContentWrapper: import("styled-components/dist/types").IStyledComponentBase<"web", import("styled-components/dist/types").Substitute<import("react").DetailedHTMLProps<import("react").HTMLAttributes<HTMLDivElement>, HTMLDivElement>, TimelineCardContentWrapperProps>> & string;
/**
 * Props for the TimelineTitleWrapper component.
 */
interface TimelineTitleWrapperProps {
    /** Controls layout for alternating cards mode. */
    $alternateCards?: boolean;
    /** Reverses the order of elements. */
    $flip?: boolean;
    /** Hides the title visually. */
    $hide?: boolean;
    /** Current timeline mode (e.g., VERTICAL, VERTICAL_ALTERNATING). */
    mode?: TimelineMode;
}
/**
 * Wrapper for the title/date section of a timeline item.
 * Handles width, alignment, and order based on props and mode.
 */
export declare const TimelineTitleWrapper: import("styled-components/dist/types").IStyledComponentBase<"web", import("styled-components/dist/types").Substitute<import("react").DetailedHTMLProps<import("react").HTMLAttributes<HTMLDivElement>, HTMLDivElement>, TimelineTitleWrapperProps>> & string;
export {};
