/**
 * Z-index hierarchy for react-chrono
 *
 * This file defines a consistent z-index layering system to prevent
 * issues with component stacking and overlapping, such as timeline points
 * appearing on top of menus.
 *
 * Lower values appear behind elements with higher values.
 *
 * When using these values, remember:
 * 1. Components that should appear "behind" should have lower z-index values
 * 2. Components that should appear "above" should have higher z-index values
 * 3. This system prevents ad-hoc z-index values that might conflict
 * 4. When creating new components, place them in the appropriate z-index range
 */
export declare const zIndex: {
    timelineLine: number;
    timelinePoint: number;
    timelineCard: number;
    controls: number;
    tooltip: number;
    modal: number;
    popover: number;
    notification: number;
};
export default zIndex;
